# esi-utils-io

## Introduction

This is a utility package with some common IO functions used by USGS earthquake 
hazard products such as ShakeMap, ground failure, and PAGER.

## Installation

From repository base, run
```
pip install esi-utils-io
```

## Tests

```
pip install pytest
pytest .
```